@@ -1,19 +1,19 @@
 
 #define HOST_CPU "mips"
 #define HOST_VENDOR "sgi"
-#define HOST_OS "irix6.2"
+#define HOST_OS "irix6.4"
 #define HOST_OS_NAME "irix6"
-#define HOST_OS_VERSION "6.2"
-#define HOST_ARCH "IP22"
-#define HOST_NAME "mako"
+#define HOST_OS_VERSION "6.4"
+#define HOST_ARCH "IP27"
+#define HOST_NAME "subzero"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Fri Feb 25 13:54:48 EST 2000"
+#define CONFIG_DATE "Wed Sep  8 03:34:00 EDT 1999"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s4"
+#define VERSION "6.0.1"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s4"
+#define VERSION "6.0.1"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "6.2"
+#define HOST_HEADER_VERSION "6.4"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA_H 1
@@ -28,7 +28,6 @@
 #define HAVE_BZERO 1
 #define HAVE_CLNT_CREATE 1
 #define HAVE_CLNT_SPCREATEERROR 1
-#define HAVE_CLOCK_GETTIME 1
 #define HAVE_FLOCK 1
 #define HAVE_GET_MYADDRESS 1
 #define HAVE_GETCWD 1
@@ -51,7 +50,6 @@
 #define HAVE_RMDIR 1
 #define HAVE_SELECT 1
 #define HAVE_SETEUID 1
-#define HAVE_SETITIMER 1
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
@@ -107,6 +105,8 @@
 #define HAVE_SYS_DIR_H 1
 #define HAVE_SYS_ERRNO_H 1
 #define HAVE_SYS_FILE_H 1
+#define HAVE_SYS_FS_AUTOFS_H 1
+#define HAVE_SYS_FS_AUTOFS_PROT_H 1
 #define HAVE_SYS_FS_EFS_CLNT_H 1
 #define HAVE_SYS_FS_NFS_H 1
 #define HAVE_SYS_FS_NFS_CLNT_H 1
@@ -165,6 +165,7 @@
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
 #define TIME_WITH_SYS_TIME 1
+#define HAVE_ST_RDEV 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_irix6.h"
 #define HAVE_STRUCT_MNTENT 1
 #define HAVE_STRUCT_NFS_ARGS 1
@@ -181,6 +182,7 @@
 #define RECVFROM_FROMLEN_TYPE int
 #define AUTH_CREATE_GIDLIST_TYPE gid_t
 #define SVC_IN_ARG_TYPE caddr_t
+#define autofs_args_t struct autofs_args
 #define ufs_args_t struct efs_args
 #define xfs_args_t struct xfs_args
 #define efs_args_t struct efs_args
@@ -202,7 +204,6 @@
 #define HAVE_EXTERN_MKSTEMP 1
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
-#define HAVE_EXTERN_SETITIMER 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
 #define HAVE_EXTERN_STRSTR 1
@@ -233,18 +234,19 @@
 #define HAVE_FS_UFS 1
 #define HAVE_FS_XFS 1
 #define HAVE_FS_EFS 1
-#define HAVE_AMU_FS_AUTO 1
-#define HAVE_AMU_FS_DIRECT 1
-#define HAVE_AMU_FS_TOPLVL 1
-#define HAVE_AMU_FS_ERROR 1
-#define HAVE_AMU_FS_INHERIT 1
-#define HAVE_AMU_FS_PROGRAM 1
-#define HAVE_AMU_FS_LINK 1
-#define HAVE_AMU_FS_LINKX 1
-#define HAVE_AMU_FS_HOST 1
-#define HAVE_AMU_FS_NFSX 1
-#define HAVE_AMU_FS_NFSL 1
-#define HAVE_AMU_FS_UNION 1
+#define HAVE_FS_AUTOFS 1
+#define HAVE_AM_FS_AUTO 1
+#define HAVE_AM_FS_DIRECT 1
+#define HAVE_AM_FS_TOPLVL 1
+#define HAVE_AM_FS_ERROR 1
+#define HAVE_AM_FS_INHERIT 1
+#define HAVE_AM_FS_PROGRAM 1
+#define HAVE_AM_FS_LINK 1
+#define HAVE_AM_FS_LINKX 1
+#define HAVE_AM_FS_HOST 1
+#define HAVE_AM_FS_NFSX 1
+#define HAVE_AM_FS_NFSL 1
+#define HAVE_AM_FS_UNION 1
 #define MOUNT_TYPE_NFS MNTTYPE_NFS
 #define MOUNT_TYPE_NFS3 MNTTYPE_NFS3
 #define MOUNT_TYPE_UFS MNTTYPE_EFS
@@ -254,6 +256,7 @@
 #define MOUNT_TYPE_MFS MNTTYPE_MFS
 #define MOUNT_TYPE_LOFS MNTTYPE_LOFS
 #define MOUNT_TYPE_AFS MNTTYPE_AFS
+#define MOUNT_TYPE_AUTOFS MNTTYPE_AUTOFS
 #define MOUNT_TYPE_CACHEFS MNTTYPE_CACHEFS
 #define MOUNT_TYPE_IGNORE MNTTYPE_IGNORE
 #define MNTTAB_TYPE_NFS "nfs"
@@ -265,6 +268,7 @@
 #define MNTTAB_TYPE_MFS "mfs"
 #define MNTTAB_TYPE_LOFS "lofs"
 #define MNTTAB_TYPE_AFS "afs"
+#define MNTTAB_TYPE_AUTOFS "autofs"
 #define MNTTAB_TYPE_CACHEFS "cachefs"
 #define MNTTAB_OPT_ACDIRMAX "acdirmax"
 #define MNTTAB_OPT_ACDIRMIN "acdirmin"
@@ -304,6 +308,7 @@
 #define MNT2_NFS_OPT_RSIZE 0x4
 #define MNT2_NFS_OPT_SOFT 0x1
 #define MNT2_NFS_OPT_SYMTTL 0x2000
+#define MNT2_NFS_OPT_TCP 0x400000
 #define MNT2_NFS_OPT_TIMEO 0x8
 #define MNT2_NFS_OPT_WSIZE 0x2
 #define HIDE_MOUNT_TYPE "ignore"
